@@ -1,5 +1,5 @@
 package Util::Medley::Hostname;
-$Util::Medley::Hostname::VERSION = '0.033';
+$Util::Medley::Hostname::VERSION = '0.034';
 use Modern::Perl;
 use Moose;
 use namespace::autoclean;
@@ -12,7 +12,7 @@ Util::Medley::Hostname - Utilities for dealing with hostnames.
 
 =head1 VERSION
 
-version 0.033
+version 0.034
 
 =cut
 
@@ -114,10 +114,14 @@ Hostname you wish to parse.
 multi method parseHostname (Str :$hostname!) {
 
     my @a = split(/\./, $hostname);
-    my $host = shift @a;
-    my $domain = join '.', @a;
+    if (@a) {
+        my $host = shift @a;
+        my $domain = join '.', @a;
+     
+        return ($host, $domain); 	
+    }
     
-    return ($host, $domain); 	
+    return $hostname;
 }
 
 multi method parseHostname (Str $hostname) {
